type TObject = {
    [key: string | number | symbol]: any;
};
/**
 * Module with a dynamically updated data.
 * Manages the state and data variables of modules and stores.
 *
 * S — stored state type (this.state).
 *
 * D — stored data type (this.data).
 */
export default class BaseController<S = TObject, D = TObject> {
    #private;
    /**
     * Module with a dynamically updated data.
     * Manages the state and data variables of modules and stores.
     *
     * @param {TObject} defaultState - default value for the state.
     * @param {TObject} defaultData - default value for stored data.
     */
    constructor(defaultState: S, defaultData: D);
    /**
     * Method for getting current state.
     */
    get state(): S;
    /**
     * Method for getting the current data stored in the module.
     */
    get data(): D;
    /**
     * Method for changing multiple module states.
     * @param {Partial<TObject>} state - an object with a new state.
     */
    setState(state: Partial<S>): void;
    /**
     * Method for changing a particular state of a module.
     * @param {keyof TObject} state - state key (name).
     * @param {TObject[keyof TObject]} value - new value for state.
     */
    setState(state: keyof S, value: S[keyof S]): void;
    /**
     * Method for resetting module state to its defaults.
     * @param {keyof TObject} keep - state keys that should not be reset.
     */
    resetState(...keep: (keyof S)[]): void;
    /**
     * Method to change multiple module data keys.
     * @param {Partial<TObject>} data - an object with a new state data.
     */
    setData(data: Partial<D>): void;
    /**
     * Method to change a specific module data key.
     * @param {keyof TObject} data - data key.
     * @param {TObject[keyof TObject]} value - new value for provided key.
     */
    setData(data: keyof D, value: D[keyof D]): void;
    /**
     * Method for resetting data stored by the module to its defaults.
     * @param {keyof TObject} keep - data keys that should not be reset.
     */
    resetData(...keep: (keyof D)[]): void;
}
export {};
